..
    Copyright (C) 2020 CERN.

    Invenio-Records-Resources is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.


Configuration
=============

.. automodule:: invenio_records_resources.config
   :members:
